@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,68 +32,71 @@ static snd_pcm_stream_t stream = SND_PCM_STREAM_CAPTURE;
 static snd_pcm_hw_params_t *hwparams = NULL;
 static char *pcm_name = "default";
 
-static unsigned int rate = 4410, exact_rate;
+static unsigned int rate = 44100, exact_rate;
 static int size;
-static snd_pcm_uframes_t frames = 512;
+static snd_pcm_uframes_t frames;
 static int dir;
 
 static char *data = NULL;
 
 
-static void
-init()
+void
+create(Context_t *ctx)
 {
-  VERBOSE(printf("[+] using %s as capture device\n", pcm_name));
+  frames = Context_get_input_size(ctx);
+
+  VERBOSE(printf("[+] %s: using capture device: %s\n", __FILE__, pcm_name));
 
   snd_pcm_hw_params_alloca(&hwparams);
 
   if (snd_pcm_open(&pcm_handle, pcm_name, stream, 0) < 0)
     xerror("error opening PCM device %s\n", pcm_name);
   else {
-    VERBOSE(printf("[+] %s ready for capture\n", pcm_name));
+    VERBOSE(printf("[+] %s: %s ready for capture\n", __FILE__, pcm_name));
   }
 
   if (snd_pcm_hw_params_any(pcm_handle, hwparams) < 0)
     xerror("error configuring PCM device %s\n", pcm_name);
   else {
-    VERBOSE(printf("[+] %s configured\n", pcm_name));
+    VERBOSE(printf("[+] %s: %s configured\n", __FILE__, pcm_name));
   }
 
   if (snd_pcm_hw_params_set_access(pcm_handle, hwparams, SND_PCM_ACCESS_RW_INTERLEAVED) < 0)
     xerror("error setting access mode\n");
   else {
-    VERBOSE(printf("[+] access mode set\n"));
+    VERBOSE(printf("[+] %s: access mode set\n", __FILE__));
   }
 
   if (snd_pcm_hw_params_set_format(pcm_handle, hwparams, SND_PCM_FORMAT_S16_LE) < 0)
     xerror("error setting format\n");
   else {
-    VERBOSE(printf("[+] format set\n"));
+    VERBOSE(printf("[+] %s: format set\n", __FILE__));
   }
 
   exact_rate = rate;
   if (snd_pcm_hw_params_set_rate_near(pcm_handle, hwparams, &exact_rate, 0) < 0)
     xerror("error setting rate\n");
   else {
-    VERBOSE(printf("[+] setting format: wanted %dHz, got %dHz\n", rate, exact_rate));
+    VERBOSE(printf("[+] %s: setting format: wanted %dHz, got %dHz\n", __FILE__, rate, exact_rate));
   }
 
   if (snd_pcm_hw_params_set_channels(pcm_handle, hwparams, 2) < 0)
     xerror("error setting channels\n");
   else {
-    VERBOSE(printf("[+] channels set\n"));
+    VERBOSE(printf("[+] %s: channels set\n", __FILE__));
   }
 
+  VERBOSE(printf("[+] %s: asking for %ld frames\n", __FILE__, frames));
   if (snd_pcm_hw_params_set_period_size_near(pcm_handle, hwparams, &frames, &dir) < 0)
     xerror("error setting period size");
   else {
-    VERBOSE(printf("[+] period size set\n"));
+    VERBOSE(printf("[+] %s: effectively using %ld frames\n", __FILE__, frames));
   }
 
   if (snd_pcm_hw_params(pcm_handle, hwparams) < 0)
     xerror("error setting HW params\n");
   else {
-    VERBOSE(printf("[+] HW params set\n"));
+    VERBOSE(printf("[+] %s: HW params set\n", __FILE__));
   }
 
   /* Use a buffer large enough to hold one period */
@@ -103,13 +106,7 @@ init()
   data = malloc(size * sizeof(char));
   if (NULL == data)
     xperror("malloc");
-}
 
-
-void
-create(Context_t *ctx)
-{
-  init();
   ctx->input = Input_new(frames);
 }
 
@@ -124,12 +121,16 @@ jthread(void *args)
 
     while (snd_pcm_readi(pcm_handle, data, frames) < 0) {
       snd_pcm_prepare(pcm_handle);
-      /* fprintf(stderr, "<<<<<<<<<<<<<<< Buffer Overrun >>>>>>>>>>>>>>>\n"); */
+#ifdef XDEBUG
+      fprintf(stderr, "[!] %s: Buffer overrun\n", __FILE__);
+#endif
     }
 
     if (!ctx->input->mute) {
       unsigned int idx = 0, n = 0;
 
+      pthread_mutex_lock(&ctx->input->mutex);
+
       for (idx = 0; idx < frames; idx++) {
 	ctx->input->data[A_LEFT][idx] =
 	  (float)(((float)(in[n])) / (float)-SHRT_MIN);
@@ -139,8 +140,8 @@ jthread(void *args)
 	n++;
       }
 
-      /* Input_set() handles the thread locking */
       Input_set(ctx->input, A_STEREO);
+      pthread_mutex_unlock(&ctx->input->mutex);
     }
   }
 
