@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -20,7 +20,6 @@
 #include <esd.h>
 #include "context.h"
 
-#define INSIZE 256
 #define FACT   0.85
 
 u_long id = 1057433999;
@@ -32,7 +31,7 @@ static int esdfd;                  /* file descriptor for device */
 static struct pollfd esdpfd;       /* to poll the fd */
 
 /* audio buffer size */
-static int esdabuf_size = INSIZE;
+static int esdabuf_size;
 
 /* audio buffer */
 static short *esdabuf;
@@ -76,7 +75,8 @@ create(Context_t *ctx)
   if (esdfd <= 0)
     xerror("Can't open socket to esd daemon \n");
 
-  esdabuf = xcalloc(esdabuf_size*2, sizeof(short));
+  esdabuf_size = Context_get_input_size(ctx);
+  esdabuf = xcalloc(esdabuf_size * 2, sizeof(short));
 
   ctx->input = Input_new(esdabuf_size);
 
@@ -107,6 +107,9 @@ jthread(void *args)
 
       if (!ctx->input->mute) {
 	int n = 0, idx;
+
+	pthread_mutex_lock(&ctx->input->mutex);
+
 	for (idx = 0; idx < esdabuf_size; idx++) {
 	  ctx->input->data[A_LEFT][idx] =
 	    (float)(((float)(esdabuf[n])) / (float)-SHRT_MIN);
@@ -116,8 +119,8 @@ jthread(void *args)
 	  n++;
 	}
 
-	/* Input_set() handles the thread locking */
 	Input_set(ctx->input, A_STEREO);
+	pthread_mutex_unlock(&ctx->input->mutex);
       }
     }
   }
