@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -29,12 +29,22 @@ static jack_client_t *client;
 static char *source_names[2] = { NULL, NULL };
 static const char **ports;
 
+// TODO: make it configuration in the rc file
+// desired input->size
+#define INSIZE 1024
+static uint16_t insize = INSIZE;
+// buffer jack samples here before copying to input->data
+static double *data[2];
+// number of jack frames to be read to reach input->size
+static uint8_t chunks;
+
 
 static void
 jack_shutdown(void *arg)
 {
-  /* TODO: do not xerror */
-  xerror("JACK shut down\n");
+  Context_t *ctx = (Context_t *)arg;
+  printf("[!] JACK: server shut down, exiting\n");
+  ctx->running = 0;
 }
 
 
@@ -45,24 +55,42 @@ process(jack_nframes_t nframes, void *arg)
   uint32_t i;
   Context_t *ctx = (Context_t *)arg;
   jack_default_audio_sample_t *in;
+  static uint8_t chunk = 0;
+  static uint16_t idx = 0;
 
-  if (nframes > ctx->input->size) {
-    VERBOSE(printf("[!] JACK: server sent more frames (%d) than input buffer size (%d)\n",
-		   nframes, ctx->input->size));
-    nframes = ctx->input->size;
-  }
+  if (!ctx->input->mute) {
+    uint16_t idx2 = idx;
 
-  int ok = 0;
-  for (chn = 0; chn < 2; chn++) {
-    in = jack_port_get_buffer(input_ports[chn], nframes);
-    if (in != NULL) {
-      for (i = 0; i < nframes; i++)
-	ctx->input->data[A_LEFT+chn][i] = in[i];
-      ok++;
+    for (chn = 0; chn < 2; chn++) {
+      in = jack_port_get_buffer(input_ports[chn], nframes);
+      if (in != NULL) {
+	for (i = 0; i < nframes; i++, idx++) {
+	  data[chn][idx] = in[i];
+	}
+	if (chn == 0) {
+	  idx = idx2;
+	}
+      }
+    }
+
+    chunk++;
+#ifdef XDEBUG
+    printf("[i] JACK: chunk= %d\n", chunk);
+#endif
+
+    if (chunk == chunks) {
+#ifdef XDEBUG
+      printf("[i] JACK: setting input, idx= %d\n", idx);
+#endif
+      pthread_mutex_lock(&ctx->input->mutex);
+      for (i = 0; i < ctx->input->size; i++) {
+	ctx->input->data[A_LEFT][i]  = data[0][i];
+	ctx->input->data[A_RIGHT][i] = data[1][i];
+      }
+      Input_set(ctx->input, A_STEREO);
+      pthread_mutex_unlock(&ctx->input->mutex);
+      idx = chunk = 0;
     }
-  }
-  if (ok == 2) {
-    Input_set(ctx->input, A_STEREO);
   }
 
   return 0;
@@ -98,11 +126,13 @@ setup_ports()
 void
 create(Context_t *ctx)
 {
+  int i;
+
   if ((client = jack_client_open(PACKAGE, JackNullOption, NULL)) == 0)
     xerror("JACK server not running ?\n");
 
   jack_set_process_callback(client, process, ctx);
-  jack_on_shutdown(client, jack_shutdown, NULL);
+  jack_on_shutdown(client, jack_shutdown, ctx);
 
   if (NULL == (source_names[0] = getenv("LEBINIOU_JACK_LEFT")))
     source_names[0] = "system:capture_1";
@@ -114,14 +144,24 @@ create(Context_t *ctx)
 
   setup_ports();
 
-  jack_nframes_t insize = jack_get_buffer_size(client);
-  printf("[i] JACK: setting input size to %d\n", insize);
+  jack_nframes_t jack_size = jack_get_buffer_size(client);
+  printf("[i] JACK: buffer size: %d\n", jack_size);
+  if (jack_size >= insize) {
+    chunks = 1;
+    insize = jack_size;
+  } else {
+    chunks = insize / jack_size;
+  }
+  printf("[i] JACK: %d chunks to read\n", chunks);
+
   ctx->input = Input_new(insize);
+  data[0] = xcalloc(insize, sizeof(double));
+  data[1] = xcalloc(insize, sizeof(double));
 
   if (jack_activate(client))
     xerror("JACK: cannot activate client\n");
 
-  for (int i = 0; i < 2; i++) {
+  for (i = 0; i < 2; i++) {
     if (jack_connect(client, ports[i], jack_port_name(input_ports[i]))) {
       fprintf(stderr, "[!] JACK: can not connect input port %s to %s\n", jack_port_name(input_ports[i]), source_names[i]);
       jack_client_close(client);
@@ -138,4 +178,6 @@ destroy(Context_t *ctx)
 {
   jack_client_close(client);
   Input_delete(ctx->input);
+  xfree(data[0]);
+  xfree(data[1]);
 }
