@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,8 +24,6 @@
 u_long id = 1235598744;
 u_long options = BE_NONE;
 
-#define USE_THREAD
-
 static const char *file = NULL;
 static SF_INFO	sfi;
 static SNDFILE *sf = NULL;
@@ -102,6 +100,7 @@ run(Context_t *ctx)
   double sample[sfi.channels];
   u_short idx;
 
+  pthread_mutex_lock(&ctx->input->mutex);
   /* lire des datas du fichier et les coller dans l'Input */
   for (idx = 0; idx < bufsize; idx++) {
     /* lecture d'une frame du son en entree, au format double (comme pour l'Input) */
@@ -130,6 +129,7 @@ run(Context_t *ctx)
 
   /* buffer pret, demander les FFT/u_data... */
   Input_set(ctx->input, A_STEREO);
+  pthread_mutex_unlock(&ctx->input->mutex);
 
   /* si lecture finie: on recommence ou on exit */
   if (frames < 1) {
