@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -147,6 +147,7 @@ jthread(void *args)
   while (ctx->running) {
     int  j;
 
+    pthread_mutex_lock(&ctx->input->mutex);
     for (j = 0; j < INSIZE; j++) {
       StereoSample  smp;
       int  i;
@@ -197,6 +198,7 @@ jthread(void *args)
 
     /* buffer written, build FFTs, etc. */
     Input_set(ctx->input, A_STEREO);
+    pthread_mutex_unlock(&ctx->input->mutex);
   }
 
   /* that's all, folks ! */
