@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,6 +24,8 @@ u_long id = 1058309664;
 u_long options = BE_SFX2D|BEQ_NORANDOM;
 char desc[] = "Pulsing box";
 
+#define BEAT_BAND 2
+
 
 void
 create(Context_t *ctx)
@@ -36,9 +38,26 @@ create(Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  float x1 = Input_get_volume(ctx->input) * MAXX;
+  if (NULL == ctx->input)
+    return;
 
-  draw_box_nc(passive_buffer(ctx),
-	      0, HHEIGHT+HHEIGHT/8,
-	      (u_short)x1, HHEIGHT-HHEIGHT/8, 250);
+  double max = ctx->input->spectrum_log[A_MONO][BEAT_BAND];
+  u_short x1;
+
+  if (max > 1.0) {
+#ifdef DEBUG
+    printf("[!] %s: max too HIGH: %f\n", __FILE__, max);
+#endif
+    max = 1.0;
+  } else if (max < 0.0) {
+#ifdef DEBUG
+    printf("[!] %s: max too LOW: %f\n", __FILE__, max);
+#endif
+    max = 0.0;
+  }
+  x1 = max * MAXX;
+
+  draw_filled_box_nc(passive_buffer(ctx),
+		     0, HHEIGHT + (HHEIGHT / 8),
+		     x1, HHEIGHT - (HHEIGHT / 8), 255);
 }
