@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -36,7 +36,7 @@ on_switch_off(Context_t *ctx)
 
 /* FIXME empirical settings, have fun understanding how this works :) */
 #define K 20
-#define L 8
+#define L 6 //8
 
 
 void
@@ -71,7 +71,7 @@ run(Context_t *ctx)
   for (i = 1; i <= L; i++)
     //somme += ctx->input->spectrum_log_norme[A_MONO][i];
     somme += ctx->input->spectrum[A_MONO][i];
-  //	somme /= L;
+  somme /= L;
 
   /* FIXME */
   /*
@@ -85,7 +85,7 @@ run(Context_t *ctx)
   /* log_max_norme_2 c'etait un mauvais nom, log_max_norme plutot ? */
   // printf("somme1= %f ", somme);
 
-#ifdef DEBUG
+#ifdef XDEBUG
   if ((somme < 0) || (somme > ctx->input->max_spectrum[A_MONO]))
     printf("[!] pulse: strange somme= %f\n", somme);
 #endif
