@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -50,7 +50,7 @@ create(Context_t *ctx)
 
 
 void
-delete(Context_t *ctx)
+destroy(Context_t *ctx)
 {
   Buffer8_delete(diff);
 }
