@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -22,7 +22,7 @@
 uint32_t id = 1172430309;
 uint32_t options = BE_GFX|BEQ_WEBCAM|BEQ_MUTE_CAM;
 char desc[] = "Webcam plugin";
-uint8_t mode = AVERAGE;
+uint8_t mode = OVERLAY;
 
 extern int webcams;
 
