@@ -1,6 +1,6 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
- *  Copyright 2014-2018 Frantz Balinski
+ *  Copyright 1994-2019 Olivier Girondel
+ *  Copyright 2014-2019 Frantz Balinski
  *
  *  This file is part of lebiniou.
  *
@@ -75,22 +75,6 @@ run(Context_t *ctx)
 }
 
 
-#ifndef EVT_DAWA
-#ifdef HAVE_SDL_H
-u_char
-on_SDL_Event(SDL_Event *e)
-{
-  if (key(e, SDLK_n)) {
-    on_switch_on();
-    return 1;
-  }
-
-  return 0;
-}
-#endif // HAVE_SDL_H
-#endif
-
-
 void
 on_switch_on(void)
 {
