@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -21,9 +21,11 @@
 
 u_long id = 1333296212;
 u_long options = BE_NONE;
+char desc[] = "RTMP streamer";
 
 
-#define FFMPEG           "ffmpeg" /* FIXME must be in $PATH */
+#define FFMPEG_CHECK     "ffmpeg -h >/dev/null 2>&1"
+#define FFMPEG           "ffmpeg"
 #define RTMP_FFMPEG_ARGS "-loglevel quiet -re -vcodec ppm -f image2pipe -i pipe: -f flv"
 #define RTMP_URL         "rtmp://localhost:1935/rtmp/"PACKAGE
 
@@ -44,10 +46,10 @@ open_rtmp()
 
   g_snprintf(cmd, MAXLEN, "%s %s %s", FFMPEG, args, url);
   if (NULL == (rtmp = popen(cmd, "w")))
-    xperror("RTMP:popen");
+    xperror("popen");
   else {
-    VERBOSE(printf("[i] RTMP: opened stream to %s\n", url));
-    VERBOSE(printf("[i] RTMP: ffmpeg args: '%s'\n", args));
+    VERBOSE(printf("[i] %s: opened stream to %s\n", __FILE__, url));
+    VERBOSE(printf("[i] %s: ffmpeg args: '%s'\n", __FILE__, args));
   }
 }
 
@@ -55,7 +57,12 @@ open_rtmp()
 void
 create(Context_t *ctx)
 {
-  open_rtmp();
+  if (check_command(FFMPEG_CHECK) == -1) {
+    printf("[!] %s: ffmpeg binary not found, plugin disabled\n", __FILE__);
+    options |= BEQ_DISABLED;
+  } else {  
+    open_rtmp();
+  }
 }
 
 
@@ -64,7 +71,7 @@ destroy(Context_t *ctx)
 {
   if (NULL != rtmp)
     if (-1 == pclose(rtmp))
-      xperror("RTMP:pclose");
+      xperror("pclose");
 }
 
 
@@ -85,7 +92,7 @@ run(Context_t *ctx)
     /* PPM header */
     res = fwrite((const void *)&buff, sizeof(char), strlen(buff), rtmp);
     if (res != strlen(buff)) {
-      fprintf(stderr, "[!] RTMP:write_header: short write (%d of %d)\n", (int)res, (int)strlen(buff));
+      fprintf(stderr, "[!] %s:write_header: short write (%d of %d)\n", __FILE__, (int)res, (int)strlen(buff));
       exit(1);
     }
 
@@ -93,7 +100,7 @@ run(Context_t *ctx)
     res = fwrite((const void *)data, sizeof(Pixel_t), RGB_BUFFSIZE, rtmp);
     xfree(data);
     if (res != RGB_BUFFSIZE) {
-      fprintf(stderr, "[!] RTMP:write_image: short write (%d of %li)\n", (int)res, RGB_BUFFSIZE);
+      fprintf(stderr, "[!] %s:write_image: short write (%d of %li)\n", __FILE__, (int)res, RGB_BUFFSIZE);
       exit(1);
     }
 
