@@ -1,5 +1,5 @@
 /*
- *  Copyright 2018 Olivier Girondel
+ *  Copyright 2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -128,7 +128,7 @@ SDL_get_event(Context_t *ctx)
 	if (ctx->params3d.scale_factor > 11)
 	  ctx->params3d.scale_factor *= 0.9;
       }
-      /* printf("scale: %d\n", ctx->params3d->scale_factor); */
+      printf("[i] scale: %d\n", ctx->params3d.scale_factor);
       break;
 
     case SDL_MOUSEBUTTONDOWN:
