@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -32,7 +32,10 @@ biniou_new(const char *datadir, const char *pluginsdir,
 #ifndef FIXED
 	   const u_short width, const u_short height,
 #endif
-	   const u_char options)
+	   const u_char options,
+	   const uint32_t input_size,
+	   const uint8_t phase_space_delay,
+	   const uint8_t span_size)
 {
   char *buf;
 
@@ -77,6 +80,9 @@ biniou_new(const char *datadir, const char *pluginsdir,
 
   /* Context */
   context = Context_new();
+  Context_set_input_size(context, input_size);
+  Context_set_phase_space_delay(context, phase_space_delay);
+  Context_set_span_size(context, span_size);
 
   /* Plugins */
   VERBOSE(printf("[+] Loading plugins\n"));
@@ -269,7 +275,7 @@ biniou_verbosity(const u_char v)
 void
 biniou_set_random_mode(const enum RandomMode r)
 {
-  Context_set_random_mode(context, r);
+  Context_set_engine_random_mode(context, r);
 }
 
 
