@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -33,7 +33,7 @@ void biniou_new(const char *, const char *, const char *, const char *,
 #ifndef FIXED
 		const u_short, const u_short,
 #endif
-		const u_char);
+		const u_char, const uint32_t, const uint8_t, const uint8_t);
 void biniou_delete();
 
 /* vla le bordel */
