@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -26,7 +26,20 @@ static GRand *brand = NULL;
 void
 b_rand_init(void)
 {
-  brand = g_rand_new();
+  uint32_t seed;
+  char *seedstr;
+
+  if ((seedstr = getenv("LEBINIOU_SEED")) != NULL) {
+    seed = xatol(seedstr);
+    VERBOSE(printf("[i] Random seed set to %d\n", seed));
+  } else {
+    struct timeval t;
+
+    gettimeofday(&t, NULL);
+    seed = t.tv_sec;
+    VERBOSE(printf("[i] No random seed, using %d\n", seed));
+  }
+  brand = g_rand_new_with_seed(seed);
 }
 
 
