@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -281,7 +281,11 @@ gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const
 
   sws_context = sws_getContext(width, height, AV_PIX_FMT_GRAY8,
 			       WIDTH, HEIGHT, AV_PIX_FMT_GRAY8,
+#ifdef __NetBSD__
+			       SWS_BILINEAR, NULL, NULL, NULL);
+#else
 			       SWS_FAST_BILINEAR, NULL, NULL, NULL);
+#endif
   if (NULL == sws_context)
     xerror("sws_getContext\n");
 
