@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -34,7 +34,7 @@ CmapFader_new(const u_short size)
   cf->dst = colormaps->cmaps[0];
   cf->fader = Fader_new(256*4);
   cf->shf = Shuffler_new(size);
-  Shuffler_set_mode(cf->shf, BS_RANDOM);
+  Shuffler_set_mode(cf->shf, Context_get_shuffler_mode(BD_COLORMAPS));
   cf->refresh = 1;
 
   CmapFader_set(cf);
