@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -34,48 +34,48 @@ extern uint8_t statistics;
 static void
 usage()
 {
-  printf("Usage: %s [options]\n\n"
-	 "\t-b, --basedir <path>\tSet base directory\n"
-	 "\t-d, --datadir <path>\tSet data directory\n"
-	 "\t-z, --schemes <file>\tSet the schemes file\n"
+  printf("Usage: " PACKAGE_NAME " [options]\n\n"
+	 "\t-b, --basedir <path>\tSet base directory [" DEFAULT_PLUGINSDIR "]\n"
+	 "\t-d, --datadir <path>\tSet data directory [" DEFAULT_DATADIR "]\n"
+	 "\t-z, --schemes <file>\tSet the schemes file [" DEFAULT_SCHEMES_FILE "]\n"
 	 "\t-f, --fullscreen\tSet fullscreen\n"
 	 "\t-h, --help\t\tDisplay this help\n"
-	 "\t-i, --input <plugin>\tSet input plugin\n"
-	 "\t-m, --maxfps <fps>\tSet maximum framerate\n"
-	 "\t-o, --output <plugin>\tSet output plugin\n"
+	 "\t-i, --input <plugin>\tSet input plugin [" DEFAULT_INPUT_PLUGIN "]\n"
+	 "\t-m, --maxfps <fps>\tSet maximum framerate [%ld]\n"
+	 "\t-o, --output <plugin>\tSet output plugin [" DEFAULT_OUTPUT_PLUGIN "]\n"
 	 "\t-r, --random <mode>\tSet auto-random mode\n"
 	 "\t-v, --version\t\tDisplay the version and exit\n"
 	 "\t-q, --quiet\t\tSuppress messages\n"
+	 "\t-c, --config <file>\tSet configuration file [~/" KEYFILE "]\n"
 #ifndef FIXED
-	 "\t-x, --width <width>\tSet width\n"
-	 "\t-y, --height <height>\tSet height\n"
+	 "\t-x, --width <width>\tSet width [%d]\n"
+	 "\t-y, --height <height>\tSet height [%d]\n"
 #endif
-	 "\t-p, --pidfile <file>\tSet the PID file\n"
-	 "\t-t, --themes <themes>\tComma-separated list of themes to use\n"
+	 "\t-p, --pidfile <file>\tSet the PID file [%s]\n"
+	 "\t-t, --themes <themes>\tComma-separated list of themes to use [biniou]\n"
 #ifdef WITH_WEBCAM
-	 "\t-W, --webcams <webcams>\tNumber of webcams (default: %d)\n"
-	 "\t-D, --device <device>\tWebcam base (default: %s)\n"
-	 "\t-c, --camflip <h|v>\tFlip webcam image horizontally/vertically\n"
+	 "\t-W, --webcams <webcams>\tNumber of webcams [%d]\n"
+	 "\t-D, --device <device>\tWebcam base [" DEFAULT_VIDEO_DEVICE "]\n"
+	 "\t-C, --camflip <h|v>\tFlip webcam image horizontally/vertically\n"
 #endif
 	 "\t-S, --stats\t\tDisplay statistics\n"
 	 "\n"
-	 "This version of %s was compiled with:\n"
-	 "\tInput plugins: %s [default: %s]\n"
-	 "\tOutput plugins: %s [default: %s]\n"
+	 "This version of " PACKAGE_STRING " was compiled with:\n"
+	 "\tInput plugins: " INPUT_PLUGINS "\n"
+	 "\tOutput plugins: " OUTPUT_PLUGINS "\n"
 	 "\n"
 #ifdef MANLINK
-	 "Manual: file://%s\n"
+	 "Manual: file://" MANLINK "\n"
 	 "\n"
 #endif
-	 , PACKAGE_NAME,
+	 , max_fps
+#ifndef FIXED
+	 , DEFAULT_WIDTH
+	 , DEFAULT_HEIGHT
+#endif
+	 , pid_file
 #ifdef WITH_WEBCAM
-	 webcams, DEFAULT_VIDEO_DEVICE,
-#endif
-	 PACKAGE_STRING,
-	 INPUT_PLUGINS, DEFAULT_INPUT_PLUGIN,
-	 OUTPUT_PLUGINS, DEFAULT_OUTPUT_PLUGIN
-#ifdef MANLINK
-	 , MANLINK
+	 , webcams
 #endif
 	 );
 
@@ -105,6 +105,7 @@ getargs(int argc, char **argv)
 		  {"output", required_argument, NULL, 'o'},
 		  {"random", required_argument, NULL, 'r'},
 		  {"quiet", no_argument, NULL, 'q'},
+		  {"config", required_argument, NULL, 'c'},
 #ifndef FIXED
 		  {"width", required_argument, NULL, 'x'},
 		  {"height", required_argument, NULL, 'y'},
@@ -113,7 +114,7 @@ getargs(int argc, char **argv)
 		  {"pidfile", required_argument, NULL, 'p'},
 		  {"themes", required_argument, NULL, 't'},
 #ifdef WITH_WEBCAM
-		  {"camflip", required_argument, NULL, 'c'},
+		  {"camflip", required_argument, NULL, 'C'},
 		  {"webcams", required_argument, NULL, 'W'},
 		  {"device", required_argument, NULL, 'D'},
 #endif
@@ -123,9 +124,9 @@ getargs(int argc, char **argv)
 
 
   /* Get command line arguments */
-  while ((ch = getopt_long(argc, argv, "b:c:d:D:fhi:m:o:p:qr:St:x:y:vW:z:", long_opt, NULL)) != -1)
+  while ((ch = getopt_long(argc, argv, "b:c:C:d:D:fhi:m:o:p:qr:St:x:y:vW:z:", long_opt, NULL)) != -1)
 #else
-  while ((ch = getopt(argc, argv, "b:c:d:D:fhi:m:o:p:qr:St:x:y:vW:z:")) != -1)
+  while ((ch = getopt(argc, argv, "b:c:C:d:D:fhi:m:o:p:qr:St:x:y:vW:z:")) != -1)
 #endif
     switch (ch) {
     case 'b':
@@ -133,8 +134,14 @@ getargs(int argc, char **argv)
 	base_dir = optarg;
       break;
 
-#ifdef WITH_WEBCAM
     case 'c':
+      /* re-read configuration file */
+      set_configuration(optarg);
+      read_keyfile();
+      break;
+
+#ifdef WITH_WEBCAM
+    case 'C':
       if (*optarg == 'h') hflip=!hflip;
       if (*optarg == 'v') vflip=!vflip;
       break;
