@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -60,10 +60,13 @@ extern unsigned short WIDTH, HEIGHT;
 #define DEC(val, maxval) do { if (!val) val = maxval-1; else --val; } while (0)
 #define INC(val, maxval) do { if (++val == maxval) val = 0; } while (0)
 
-#define SAVEDIR ".lebiniou/sequences"
+/* default configuration file */
+#define KEYFILE "." PACKAGE_NAME "rc"
 
+/* banks */
 #define MAX_BANKS 12
 
+/* 3D z-buffer */
 #define ZMAX 6.0
 
 #endif /* __BINIOU_CONSTANTS_H */
