@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,9 +24,39 @@
 #include "images.h"
 #include "sequences.h"
 
+#ifdef WITH_WEBCAM
+#define MAX_TIMERS 4
+#else
+#define MAX_TIMERS 3
+#endif
 
-#define DELAY_MIN 15
-#define DELAY_MAX 30
+/* Auto-change timers and modes */
+static char *delay_names[MAX_TIMERS] = {
+  "colormaps",
+  "images",
+  "sequences"
+#ifdef WITH_WEBCAM
+  , "webcams"
+#endif
+};
+
+static int delays[MAX_TIMERS][2] = {
+  { DELAY_MIN, DELAY_MAX }, // colormaps
+  { DELAY_MIN, DELAY_MAX }, // images
+  { DELAY_MIN, DELAY_MAX }  // sequences
+#ifdef WITH_WEBCAM
+  , { DELAY_MIN, DELAY_MAX }  // webcams
+#endif
+};
+
+static enum ShufflerMode random_modes[MAX_TIMERS] = {
+  BS_RANDOM,  // colormaps
+  BS_RANDOM,  // images
+  BS_SHUFFLE  // sequences
+#ifdef WITH_WEBCAM
+  , BS_CYCLE  // webcams
+#endif
+};
 
 
 #ifdef WITH_WEBCAM
@@ -106,7 +136,6 @@ Context_new()
       for (i = 0; i < CAM_SAVE; i++)
 	ctx->cam_save[k][i] = Buffer8_new();
       ctx->cam_ref[k] = Buffer8_new();
-      ctx->rgba_cam_buffers[k] = BufferRGBA_new();
     }
   }
 #endif
@@ -122,19 +151,20 @@ Context_new()
     VERBOSE(printf("[+] Creating images fader (%i images)\n", images->size));
     ctx->imgf = ImageFader_new(images->size);
 
-    VERBOSE(printf("[+] Creating images timer\n"));
-    ctx->a_images = Alarm_new(DELAY_MIN, DELAY_MAX);
+    VERBOSE(printf("[+] Creating images timer (%d..%d)\n", delays[BD_IMAGES][0], delays[BD_IMAGES][1]));
+    ctx->a_images = Alarm_new(delays[BD_IMAGES][0], delays[BD_IMAGES][1]);
   }
 
   if (colormaps != NULL) {
     VERBOSE(printf("[+] Creating colormaps fader (%i colormaps)\n", colormaps->size));
     ctx->cf = CmapFader_new(colormaps->size);
 
-    VERBOSE(printf("[+] Creating colormaps timer\n"));
-    ctx->a_cmaps = Alarm_new(DELAY_MIN, DELAY_MAX);
+    VERBOSE(printf("[+] Creating colormaps timer (%d..%d)\n", delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]));
+    ctx->a_cmaps = Alarm_new(delays[BD_COLORMAPS][0], delays[BD_COLORMAPS][1]);
   }
 
-  ctx->a_random = Alarm_new(DELAY_MIN, DELAY_MAX);
+  VERBOSE(printf("[+] Creating sequences timer (%d..%d)\n", delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]));
+  ctx->a_random = Alarm_new(delays[BD_SEQUENCES][0], delays[BD_SEQUENCES][1]);
   ctx->random_mode = BR_NONE;
 
   VERBOSE(printf("[+] Initializing sequence manager\n"));
@@ -157,25 +187,19 @@ Context_new()
 
   ctx->outputs = NULL;
 
-#ifdef FEAT_TARGET
-  ctx->target = 1; /* maybe someday we want a switch to disable,
-		      or worse, a global variable :) */
   ctx->target_pic = Image8_new();
-  /* FIXME temp */
-  {
-    extern char *data_dir;
-    gchar *tmp;
-    int res;
 
-    tmp = g_strdup_printf("%s/%s", data_dir, "images/z-biniou-tv-1.png");
-    VERBOSE(printf("[+] Loading '%s'\n", tmp));
-    res = Image8_load_PNG(ctx->target_pic, tmp);
-    assert(!res);
-    if (res == -1)
-      xerror("Image8_load_PNG(%s)\n", tmp);
-    g_free(tmp);
+  extern char *data_dir;
+  gchar *tmp;
+  int res;
+
+  tmp = g_strdup_printf("%s/%s", data_dir, "images/z-biniou-tv-1.png");
+  VERBOSE(printf("[+] Loading '%s'\n", tmp));
+  res = Image8_load_PNG(ctx->target_pic, tmp);
+  g_free(tmp);
+  if (res == -1) {
+    Buffer8_randomize(ctx->target_pic->buff);
   }
-#endif
 
 #ifdef WITH_WEBCAM
   VERBOSE(printf("[i] Initializing %d webcams base: %s\n", webcams, video_base));
@@ -185,6 +209,19 @@ Context_new()
 
   for (i = 0; i < webcams; i++)
     Buffer8_copy(ctx->target_pic->buff, ctx->cam_save[i][0]);
+
+  if (webcams > 1) {
+    VERBOSE(printf("[+] Creating webcams timer (%d..%d)\n", delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]));
+    ctx->a_webcams = Alarm_new(delays[BD_WEBCAMS][0], delays[BD_WEBCAMS][1]);
+    Alarm_init(ctx->a_webcams);
+
+    VERBOSE(printf("[+] Creating webcams shuffler (%d webcams)\n", webcams));
+    ctx->webcams_shuffler = Shuffler_new(webcams);
+    Shuffler_set_mode(ctx->webcams_shuffler, Context_get_shuffler_mode(BD_WEBCAMS));
+#ifdef DEBUG
+    Shuffler_verbose(ctx->webcams_shuffler);
+#endif
+  }
 #endif
 
   return ctx;
@@ -220,6 +257,10 @@ Context_delete(Context_t *ctx)
       Context_close_webcam(i);
   }
   xfree(video_base);
+  if (webcams > 1) {
+    Shuffler_delete(ctx->webcams_shuffler);
+    Alarm_delete(ctx->a_webcams);
+  }
 #endif
 
   VERBOSE(printf("[i] %lu frames, %lu events\n", ctx->frames, ctx->nb_events));
@@ -246,7 +287,6 @@ Context_delete(Context_t *ctx)
       for (i = 0; i < CAM_SAVE; i++)
 	Buffer8_delete(ctx->cam_save[k][i]);
       Buffer8_delete(ctx->cam_ref[k]);
-      BufferRGBA_delete(ctx->rgba_cam_buffers[k]);
     }
   }
 #endif
@@ -274,10 +314,8 @@ Context_delete(Context_t *ctx)
   b_timer_delete(ctx->timer);
   b_timer_delete(ctx->fps_timer);
 
-#ifdef FEAT_TARGET
   if (NULL != ctx->target_pic)
     Image8_delete(ctx->target_pic);
-#endif
 
   xfree(ctx);
 }
@@ -467,7 +505,7 @@ Context_set_max_fps(Context_t *ctx, const u_short max_fps)
 
 
 void
-Context_set_random_mode(Context_t *ctx, const enum RandomMode r)
+Context_set_engine_random_mode(Context_t *ctx, const enum RandomMode r)
 {
   ctx->random_mode = r;
 }
@@ -641,3 +679,87 @@ Context_push_webcam(Context_t *ctx, Buffer8_t *buff, const int cam)
   ctx->cam_save[cam][0] = buff;
 }
 #endif
+
+
+void
+Context_set_delay(const enum RandomDelays what, const int min, const int max)
+{
+  if ((max <= min) || (min < 1) || (max < 1)) {
+    xerror("Set random delay for %s: max (%d) must be > min (%d), both values must be > 1\n",
+	   delay_names[what], max, min);
+  }
+
+#ifdef DEBUG
+  printf("[i] Setting min..max delays for %s: %d..%d\n", delay_names[what], min, max);
+#endif
+  delays[what][0] = min;
+  delays[what][1] = max;
+}
+
+
+void
+Context_set_shuffler_mode(const enum RandomDelays what, const enum ShufflerMode mode)
+{
+  random_modes[what] = mode;
+}
+
+
+enum ShufflerMode
+Context_get_shuffler_mode(const enum RandomDelays what)
+{
+  return random_modes[what];
+}
+
+
+void
+Context_set_input_size(Context_t *ctx, const uint32_t input_size)
+{
+  ctx->input_size = input_size;
+}
+
+
+uint32_t
+Context_get_input_size(const Context_t *ctx)
+{
+  return ctx->input_size;
+}
+
+
+void
+Context_set_phase_space_delay(Context_t *ctx, const uint8_t phase_space_delay)
+{
+  ctx->phase_space_delay = phase_space_delay;
+}
+
+
+uint8_t
+Context_get_phase_space_delay(const Context_t *ctx)
+{
+  return ctx->phase_space_delay;
+}
+
+
+uint32_t
+Context_get_phase_space_samples(const Context_t *ctx)
+{
+  if (ctx->input != NULL) {
+    return ctx->input->size - 2 * ctx->phase_space_delay;
+  } else {
+    return 0;
+  }
+}
+
+
+void
+Context_set_span_size(Context_t *ctx, const uint8_t span_size)
+{
+  assert(span_size > 0);
+  ctx->span_size = span_size;
+}
+
+
+uint8_t
+Context_get_span_size(const Context_t *ctx)
+{
+  return ctx->span_size;
+}
