@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -37,6 +37,16 @@
 
 enum RandomMode { BR_NONE=0, BR_SEQUENCES, BR_SCHEMES, BR_BOTH } RandomMode_e;
 
+/* Random changes delays */
+#define DELAY_MIN 15
+#define DELAY_MAX 30
+enum RandomDelays { BD_COLORMAPS=0, BD_IMAGES=1, BD_SEQUENCES=2
+#ifdef WITH_WEBCAM
+		    , BD_WEBCAMS=3
+#endif
+} RandomDelays_e;
+
+
 #define ACTIVE_BUFFER  0
 #define PASSIVE_BUFFER 1
 #define SAVE_BUFFER    2
@@ -75,7 +85,6 @@ typedef struct Context_s {
   /* webcam */
   Buffer8_t *cam_save[MAX_CAMS][CAM_SAVE];
   Buffer8_t *cam_ref[MAX_CAMS];
-  BufferRGBA_t *rgba_cam_buffers[MAX_CAMS];
   u_char ref_taken[MAX_CAMS];
 #endif
 
@@ -93,9 +102,16 @@ typedef struct Context_s {
   /* TODO move this to a global */
   Params3d_t params3d;
 
+  /* auto-change sequences (user or generated) */
   enum RandomMode random_mode;
   Alarm_t  *a_random;
 
+#ifdef WITH_WEBCAM
+  /* auto-change webcams */
+  Shuffler_t *webcams_shuffler;
+  Alarm_t    *a_webcams;
+#endif
+
   u_long   frames;
 
   GList    *events;
@@ -141,12 +157,13 @@ typedef struct Context_s {
 #endif
 
   /* Target */
-#ifdef FEAT_TARGET
-  u_char     target:1;
   Image8_t *target_pic;
-#endif
 
   Plugin_t *locked; // Locked plugin feature
+
+  uint32_t input_size;
+  uint8_t phase_space_delay;
+  uint8_t span_size;
 } Context_t;
 
 
@@ -164,7 +181,7 @@ int  Context_add_rand(Sequence_t *, const enum PluginOptions, const int);
 void Context_randomize(Context_t *);
 
 void Context_set_max_fps(Context_t *, const u_short);
-void Context_set_random_mode(Context_t *, const enum RandomMode);
+void Context_set_engine_random_mode(Context_t *, const enum RandomMode);
 
 void Context_insert_plugin(Context_t *, Plugin_t *);
 void Context_remove_plugin(Context_t *, Plugin_t *);
@@ -243,4 +260,19 @@ void Context_make_GL_RGBA_texture(Context_t *ctx, const u_char);
 void Context_make_GL_gray_texture(Context_t *ctx, const u_char);
 #endif
 
+void Context_set_delay(const enum RandomDelays, const int, const int);
+void Context_set_shuffler_mode(const enum RandomDelays, const enum ShufflerMode);
+enum ShufflerMode Context_get_shuffler_mode(const enum RandomDelays);
+
+void Context_set_input_size(Context_t *, const uint32_t);
+uint32_t Context_get_input_size(const Context_t *);
+
+void Context_set_phase_space_delay(Context_t *, const uint8_t);
+uint8_t Context_get_phase_space_delay(const Context_t *);
+
+uint32_t Context_get_phase_space_samples(const Context_t *);
+
+void Context_set_span_size(Context_t *, const uint8_t);
+uint8_t Context_get_span_size(const Context_t *);
+
 #endif /* __BINIOU_CONTEXT_H */
