@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -104,6 +104,8 @@ Context_event(Context_t *ctx, const Event_t *e)
 {
   int i;
   GSList *outputs = ctx->outputs;
+  uint8_t delay; // current phase-space delay
+  uint8_t span; // spline span size
 
   switch (e->cmd) {
   case BC_QUIT:
@@ -214,6 +216,10 @@ Context_event(Context_t *ctx, const Event_t *e)
       return 1;
 #endif
 
+    case BA_MUTE:
+      Input_toggle_mute(ctx->input);
+      return 1;
+
     default:
       return 0;
     }
@@ -254,13 +260,19 @@ Context_event(Context_t *ctx, const Event_t *e)
       Context_display_random(ctx);
       return 1;
 
-    case BA_FPS:
-      if (ctx->sync_fps && (ctx->max_fps > 5)) {
-	Context_set_max_fps(ctx, ctx->max_fps-5);
-	return 1;
-      } else {
-	return 0;
+    case BA_DELAY:
+      if ((delay = Context_get_phase_space_delay(ctx)) > 1) {
+	Context_set_phase_space_delay(ctx, --delay);
+	printf("[i] Phase-space delay: %d\n", delay);
       }
+      return 1;
+
+    case BA_SPAN:
+      if ((span = Context_get_span_size(ctx)) > 1) {
+	Context_set_span_size(ctx, --span);
+	printf("[i] Spline span size: %d\n", span);
+      }
+      return 1;
 
     default:
       return 0;
@@ -303,14 +315,6 @@ Context_event(Context_t *ctx, const Event_t *e)
       Context_display_random(ctx);
       return 1;
 
-    case BA_FPS:
-      if (ctx->sync_fps) {
-	Context_set_max_fps(ctx, ctx->max_fps+5);
-	return 1;
-      } else {
-	return 0;
-      }
-
 #ifdef WITH_WEBCAM
     case BA_WEBCAM:
       if (webcams) {
@@ -321,6 +325,20 @@ Context_event(Context_t *ctx, const Event_t *e)
       return 1;
 #endif
 
+    case BA_DELAY:
+      if ((delay = Context_get_phase_space_delay(ctx)) < 255) {
+	Context_set_phase_space_delay(ctx, ++delay);
+	printf("[i] Phase-space delay: %d\n", delay);
+      }
+      return 1;
+
+    case BA_SPAN:
+      if ((span = Context_get_span_size(ctx)) < 50) {
+	Context_set_span_size(ctx, ++span);
+	printf("[i] Spline span size: %d\n", span);
+       }
+      return 1;
+
     default:
       return 0;
     }
