@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -29,6 +29,11 @@
 
 #define BARSIZE (HEIGHT/20) /* Colormap bar size */
 
+#ifdef WITH_WEBCAM
+extern int webcams;
+#endif
+
+
 static void
 Context_boundary(Context_t *ctx)
 {
@@ -64,6 +69,8 @@ Context_sync(Context_t *ctx)
 
   if (sleep > 0)
     ms_sleep(sleep*MFACTOR);
+
+  b_timer_start(ctx->fps_timer);
 }
 
 
@@ -74,7 +81,6 @@ Context_sequence(Context_t *ctx)
   uint16_t count = 0;
 
   tmp = ctx->sm->cur->layers;
-  b_timer_start(ctx->fps_timer);
 
 #ifdef WITH_GL
   ctx->texture_ready = ctx->texture_used = ctx->gl_done = 0;
@@ -126,12 +132,11 @@ Context_sequence(Context_t *ctx)
 
     tmp = g_list_next(tmp);
   }
-#ifdef FEAT_TARGET
-  if (!count && ctx->random_mode && ctx->target) {
+
+  if (!count && ctx->random_mode) {
     assert(NULL != ctx->target_pic);
     Buffer8_copy(ctx->target_pic->buff, active_buffer(ctx));
   }
-#endif
 }
 
 
@@ -141,6 +146,10 @@ Context_run(Context_t *ctx)
   Plugin_t *input = ctx->input_plugin;
   GSList *outputs = ctx->outputs;
 
+  /* sync fps */
+  if (ctx->sync_fps)
+    Context_sync(ctx);
+
   /* Auto-change sequence */
   if (Alarm_ring(ctx->a_random)) {
     if (ctx->random_mode == BR_SCHEMES) {
@@ -191,6 +200,17 @@ Context_run(Context_t *ctx)
     }
   }
 
+#ifdef WITH_WEBCAM
+  /* Auto-change webcam */
+  if ((webcams > 1) && Alarm_ring(ctx->a_webcams)) {
+    u_short cam_no = Shuffler_get(ctx->webcams_shuffler);
+    ctx->cam = cam_no;
+#ifdef DEBUG
+    printf("[i] Using webcam #%d\n", cam_no);
+#endif
+  }
+#endif
+
   /* If we have an input plugin that runs in non-threaded mode,
    * call it now */
   if ((NULL != input) && (NULL != input->run)) {
@@ -239,11 +259,6 @@ Context_run(Context_t *ctx)
   /* The sequence */
   Context_sequence(ctx);
 
-  /* sync fps */
-  /* FIXME peut-etre le bouger en fin de boucle ? --oliv3 */
-  if (ctx->sync_fps)
-    Context_sync(ctx);
-
   /* draw 3D boundary */
   Context_boundary(ctx);
 
