@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -17,7 +17,7 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libavutil/mem.h>
+#include <libswscale/swscale.h>
 #include "image_8bits.h"
 #include "pnglite.h"
 
@@ -61,76 +61,6 @@ Image8_delete(Image8_t *p)
 }
 
 
-static Pixel_t
-rgb2y(const u_char r, const u_char g, const u_char b)
-{
-  float sum = 0.0;
-
-  sum += (r * 0.299);
-  sum += (g * 0.587);
-  sum += (b * 0.114);
-
-  return (Pixel_t)sum;
-}
-
-
-static Pixel_t *
-PNG_to_Y(const png_t *png, const u_char *src)
-{
-  Pixel_t *res = NULL, *dst = NULL;
-  size_t size, i;
-
-  size = png->width * png->height;
-  res = av_malloc(size*sizeof(Pixel_t));
-  dst = res;
-
-  switch (png->color_type) {
-  case PNG_GREYSCALE:
-    memcpy(dst, (const void *)src, size*sizeof(Pixel_t));
-    break;
-
-  case PNG_TRUECOLOR:
-    for (i = 0; i < size; i++, dst++) {
-      char r, g, b;
-
-      r = *src++; g = *src++; b = *src++;
-      *dst = rgb2y(r, g, b);
-    }
-    break;
-
-  case PNG_INDEXED:
-    /* TODO: unhandled ? */
-    xerror("PNG_to_Y: PNG_INDEXED not yet implemented\n");
-    break;
-
-  case PNG_GREYSCALE_ALPHA:
-    for (i = 0; i < size; i++, dst++) {
-      char y;
-
-      y = *src++;
-      src++; /* Skip alpha component */
-      *dst = y;
-    }
-    break;
-
-  case PNG_TRUECOLOR_ALPHA:
-    for (i = 0; i < size; i++, dst++) {
-      char r, g, b;
-
-      r = *src++; g = *src++; b = *src++;
-      src++; /* Skip alpha component */
-      *dst = rgb2y(r, g, b);
-    }
-    break;
-
-  default:
-    xerror("PNG_to_Y: unknown color_type= %d\n", png->color_type);
-  }
-
-  return res;
-}
-
-
 int
 Image8_load_PNG(Image8_t *pic, const char *filename)
 {
@@ -139,36 +69,93 @@ Image8_load_PNG(Image8_t *pic, const char *filename)
 
   res = png_open_file_read(&png, filename);
   if (PNG_NO_ERROR == res) {
-    u_char *data = NULL;
-    size_t size;
-
-    size = png.width * png.height * png.bpp;
-    data = xmalloc(size*sizeof(u_char));
+    size_t size = png.width * png.height * png.bpp;
+    u_char *data = xmalloc(size * sizeof(u_char));
 
     res = png_get_data(&png, data);
     if (PNG_NO_ERROR == res) {
-      Pixel_t *y = NULL;
-      Pixel_t *dst = pic->buff->buffer;
+      /* source */
+      enum AVPixelFormat srcFormat = AV_PIX_FMT_NONE;
+      int srcStride[4] = { 0, 0, 0, 0 };
+      const uint8_t *srcSlice[4] = { NULL, NULL, NULL, NULL };
+      /* destination */
+      const enum AVPixelFormat dstFormat = AV_PIX_FMT_GRAY8;
+      const int dstStride[4] = { WIDTH, 0, 0, 0 };
+      uint8_t *dstSlice[4] = { NULL, NULL, NULL, NULL };
+      struct SwsContext *sws_context = NULL;
+      int ret;
 
-      y = PNG_to_Y(&png, data);
-      xfree(data);
+      srcSlice[0] = (const uint8_t *)data;
+      dstSlice[0] = (uint8_t *)pic->buff->buffer;
 
-      if ((png.width != WIDTH) || (png.height != HEIGHT)) {
-	gray_scale(dst, png.width, png.height, y);
-	av_free(y);
-      } else {
-	xfree(pic->buff->buffer);
-	pic->buff->buffer = y;
+      /* set srcFormat from PNG infos */
+      switch (png.color_type) {
+      case PNG_GREYSCALE:
+	srcFormat = AV_PIX_FMT_GRAY8;
+	srcStride[0] = png.width;
+	break;
+
+      case PNG_TRUECOLOR:
+	srcFormat = AV_PIX_FMT_RGB24;
+	srcStride[0] = png.width * 3;
+	break;
+
+      case PNG_INDEXED:
+	/* TODO: unhandled */
+	xerror("Image8_load_PNG: PNG_INDEXED not yet implemented\n");
+	break;
+
+      case PNG_GREYSCALE_ALPHA:
+	/* TODO: unhandled */
+	xerror("Image8_load_PNG: PNG_GREYSCALE_ALPHA not yet implemented\n");
+	break;
+
+      case PNG_TRUECOLOR_ALPHA:
+	srcFormat = AV_PIX_FMT_RGBA;
+	srcStride[0] = png.width * 4;
+	break;
+
+      default:
+	xerror("Image8_load_PNG: unknown PNG color type %d\n", png.color_type);
+	break;
       }
+
+      /* create context */
+      sws_context = sws_getContext(png.width, png.height, srcFormat,
+				   WIDTH, HEIGHT, dstFormat,
+#ifdef __NetBSD__
+				   SWS_BILINEAR, NULL, NULL, NULL
+#else
+                                   SWS_FAST_BILINEAR, NULL, NULL, NULL
+#endif
+				   );
+      if (NULL == sws_context)
+	xerror("sws_getContext\n");
+
+      /* rescale (size and color space) */
+      ret = sws_scale(sws_context,
+		      srcSlice,
+		      srcStride,
+		      0,
+		      png.height,
+		      dstSlice,
+		      dstStride);
+      if (ret < 0)
+	xerror("sws_scale\n");
+
+      /* free context and data */
+      sws_freeContext(sws_context);
+      xfree(data);
+      /* flip image */
       Buffer8_flip_v(pic->buff);
     } else {
-      static int verbose = 1;
+      static int verbose1 = 1;
 
       fprintf(stderr, "[!] png_get_data: %s (%s)\n", png_error_string(res), filename);
-      if (verbose) {
+      if (verbose1) {
 	fprintf(stderr, "[!] if this is an indexed PNG, convert it to non-indexed\n");
 	fprintf(stderr, "[!] also, remove any comments from the PNG\n");
-	verbose = 0;
+	verbose1 = 0;
       }
       xfree(data);
       png_close_file(&png);
@@ -176,7 +163,13 @@ Image8_load_PNG(Image8_t *pic, const char *filename)
       return -1;
     }
   } else {
+    static int verbose2 = 1;
+
     fprintf(stderr, "[!] png_open_file_read: %s (%s)\n", png_error_string(res), filename);
+    if (verbose2) {
+      fprintf(stderr, "[!] Please remove any comments from this PNG file\n");
+      verbose2 = 0;
+    }
     if (PNG_FILE_ERROR != res)
       png_close_file(&png);
 
