@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -26,8 +26,8 @@
 #if HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
-#if HAVE_SYS_POLL_H
-#include <sys/poll.h>
+#if HAVE_POLL_H
+#include <poll.h>
 #endif
 #if HAVE_SYS_TIME_H
 #include <sys/time.h>
