@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -19,42 +19,13 @@
 
 #include "biniou.h"
 
-// #define XDEBUG
-
-/*
- * TODO cheesy display of the plan computed
- * TODO wisdom support (~/.lebiniou/biniou.wisdom)
- */
-
 float phase = 1.0;
 
-/* define to create the FFTW plan in a thread */
-/* #define THREAD_PLAN */
-
-static void
-Input_rfftw_create_plan(Input_t *input)
-{
-  int c;
-
-  for (c = 0; c < 3; ++c)
-    input->plan_fft[c] = fftw_plan_r2r_1d(input->size,
-					  input->data[c],
-					  input->out[c],
-					  (fftw_r2r_kind)FFTW_FORWARD,
-					  FFTW_MEASURE
-					  /* FFTW_REDFT00, */
-					  /* FFTW_ESTIMATE */);
-
-}
-
 
 Input_t *
 Input_new(const uint32_t size)
 {
   uint32_t c;
-#ifdef THREAD_PLAN
-  pthread_t fftw_thread;
-#endif
 
   Input_t *input = xcalloc(1, sizeof(Input_t));
 
@@ -68,25 +39,26 @@ Input_new(const uint32_t size)
 		 input->size, input->spectrum_size));
 
   for (c = 0; c < 3; c++) {
-    /* FIXME breaks when compiling without libFFTW */
-    input->data[c]   = (double *)fftw_malloc(sizeof(double)*input->size);
+    input->data[c]   = fftw_alloc_real(input->size);
     input->data_u[c] = xcalloc(input->size, sizeof(double));
-    input->out[c] = (double *)fftw_malloc(sizeof(double) * input->size);
-    input->spectrum[c] = xcalloc(input->spectrum_size, sizeof(double));
-    input->spectrum_norme[c] = xcalloc(input->spectrum_size, sizeof(double));
+    input->out[c]    = fftw_alloc_complex(input->spectrum_size);
+
+    input->plan_fft[c] = fftw_plan_dft_r2c_1d(input->size,
+					      input->data[c],
+					      input->out[c],
+					      FFTW_MEASURE);
+
+    input->spectrum[c]     = xcalloc(input->spectrum_size, sizeof(double));
     input->spectrum_log[c] = xcalloc(input->spectrum_size, sizeof(double));
-    input->spectrum_log_norme[c] = xcalloc(input->spectrum_size, sizeof(double));
   }
 
   for (c = 0; c < input->size; c++) {
-    input->data[A_LEFT][c] = input->data_u[A_LEFT][c] = 0;
+    input->data[A_LEFT][c]  = input->data_u[A_LEFT][c]  = 0;
     input->data[A_RIGHT][c] = input->data_u[A_RIGHT][c] = 0;
   }
 
-#ifdef THREAD_PLAN
-  pthread_create(&fftw_thread, NULL, Input_rfftw_create_plan_threaded, input);
-#else
-  Input_rfftw_create_plan(input);
+#ifdef DEBUG
+  input->timer = b_timer_new();
 #endif
 
   return input;
@@ -103,25 +75,16 @@ Input_delete(Input_t *input)
     xfree(input->data_u[c]);
     fftw_free(input->out[c]);
     xfree(input->spectrum[c]);
-    xfree(input->spectrum_norme[c]);
     xfree(input->spectrum_log[c]);
-    xfree(input->spectrum_log_norme[c]);
     fftw_destroy_plan(input->plan_fft[c]);
   }
 
+#ifdef DEBUG
+  b_timer_delete(input->timer);
+#endif
+
   xfree(input);
-}
-
-
-void *
-Input_rfftw_create_plan_threaded(void *huhu)
-{
-  Input_t *input = (Input_t *)huhu;
-
-  Input_rfftw_create_plan(input);
-  VERBOSE(printf("[i] FFTW plan created\n"));
-
-  pthread_exit(NULL);
+  fftw_cleanup();
 }
 
 
@@ -153,51 +116,57 @@ Input_do_fft(Input_t *input)
   int c;
   uint32_t k;
 
-#ifdef THREAD_PLAN
-  if (input->plan_fft != NULL)
+#ifdef DEBUG
+  b_timer_start(input->timer);
 #endif
-    /* could be optimized, ie only do FFTs on LEFT and RIGHT and compute MONO spectrums.
-       well, i'm too lazy :) --oliv3 */
-    for (c = 0; c < 3; c++)
-      fftw_execute(input->plan_fft[c]);
+
+  for (c = 0; c < 3; c++)
+    fftw_execute(input->plan_fft[c]);
 
   for (c = 0; c < 3; c++) {
-    for (k = 0; k < input->size; k++) {
+    for (k = 0; k < input->spectrum_size; k++) {
       input->out[c][k] /= (float)input->size;
-      /*  printf("(%d %d %f) ", c, k, input->out[c][k]); */
+      /* printf("(%d %d %f) ", c, k, input->out[c][k]); */
     }
-    for (k = 0; k < input->spectrum_size; k++)
+
+    for (k = 0; k < input->spectrum_size; k++) {
+      // input->spectrum[c][k] = cabs(input->out[c][k]);
+      // normalize to [0.0..+1.0]
+      input->spectrum[c][k] = cabs(input->out[c][k]) * M_SQRT1_2; // == / sqrtf(2.0);
+      assert(input->spectrum[c][k] >= 0);
+      assert(input->spectrum[c][k] <= 1.0);
+    }
+
+    for (k = 0; k < input->spectrum_size; k++) {
       input->spectrum[c][k] = input->out[c][k];
+      // assert(input->spectrum[c][k] >= 0);
+    }
   }
 
   for (c = 0; c < 3; c++) {
     int new_max = Input_seek_max_spectrum(input, c);
 
     for (k = 0; k < input->spectrum_size; ++k) {
-      input->spectrum_norme[c][k]     = sqrtf(input->spectrum[c][k]);
       /* Log toussa */
       /* log1p(x)=logf(x+1) */
-      input->spectrum_log  [c][k]     = log1p(input->spectrum[c][k]) / (M_LN2 / M_LN10);
-      input->spectrum_log_norme[c][k] = log1p(input->spectrum_norme[c][k]) / (M_LN2 / M_LN10);
+      input->spectrum_log[c][k] = log1p(input->spectrum[c][k]) / (M_LN2 / M_LN10);
     }
 
-    input->max_spectrum_norme[c] = input->spectrum_norme[c][new_max];
     input->max_spectrum_log[c] = input->spectrum_log[c][new_max];
-    input->max_spectrum_log_norme[c] = input->spectrum_log_norme[c][new_max];
 
 #ifdef XDEBUG
-    printf("[s] Spectrum: max on channel %d\n"
-	   "[s]   spectrum: %f\n"
-	   "[s]   spectrum_norme: %f\n"
-	   "[s]   spectrum_log: %f\n"
-	   "[s]   spectrum_log_norme: %f\n\n",
-	   c,
-	   input->max_spectrum[c],
-	   input->max_spectrum_norme[c],
-	   input->max_spectrum_log[c],
-	   input->max_spectrum_log_norme[c]);
+    if (c == A_MONO) {
+      printf("[s] %d % 3d\tspectrum: %f\tspectrum_log: %f\n",
+	     c, new_max,
+	     input->max_spectrum[c],
+	     input->max_spectrum_log[c]);
+    }
 #endif
   }
+
+#ifdef XDEBUG
+  printf("[i] FFT time: %f ms\n", b_timer_elapsed(input->timer) * 1000);
+#endif
 }
 
 
@@ -217,42 +186,38 @@ Input_set(Input_t *input, u_char mode)
    * A_MONO   => copy A_MONO to A_LEFT and A_RIGHT
    * A_STEREO => compute A_MONO as the average of A_LEFT and A_RIGHT
    */
-  uint32_t i, j;
+  uint32_t i;
 
-  pthread_mutex_lock(&input->mutex);
-
-  if (mode == A_MONO)
-    for (i = 0, j = 0; i < input->size; i++, j++) {
+  if (mode == A_MONO) {
+    for (i = 0; i < input->size; i++) {
       /* clamp values */
       input->data[A_MONO][i] = Input_clamp(input->data[A_MONO][i]);
 
       /* set input from A_MONO source */
-      input->data_u[A_MONO][j] = (input->data[A_MONO][i] + 1.0) / 2;
+      input->data_u[A_MONO][i] = (input->data[A_MONO][i] + 1.0) / 2.0;
 
       /* copy to A_LEFT and A_RIGHT */
-      input->data[A_LEFT][j] = input->data[A_RIGHT][j] = input->data[A_MONO][i];
-      input->data_u[A_LEFT][j] = input->data_u[A_RIGHT][j] = input->data_u[A_MONO][i];
+      input->data[A_LEFT][i] = input->data[A_RIGHT][i] = input->data[A_MONO][i];
+      input->data_u[A_LEFT][i] = input->data_u[A_RIGHT][i] = input->data_u[A_MONO][i];
     }
-  else {
+  } else {
     assert(mode == A_STEREO);
-    for (i = 0, j = 0; i < input->size; i++, j++) {
+    for (i = 0; i < input->size; i++) {
       /* clamp values */
       input->data[A_LEFT][i] = Input_clamp(input->data[A_LEFT][i]);
       input->data[A_RIGHT][i] = Input_clamp(input->data[A_RIGHT][i]);
 
       /* set input from A_LEFT and A_RIGHT */
-      input->data_u[A_LEFT][j] = (input->data[A_LEFT][i] + 1.0) / 2;
-      input->data_u[A_RIGHT][j] = (input->data[A_RIGHT][i] + 1.0) / 2;
+      input->data_u[A_LEFT][i] = (input->data[A_LEFT][i] + 1.0) / 2.0;
+      input->data_u[A_RIGHT][i] = (input->data[A_RIGHT][i] + 1.0) / 2.0;
 
       /* compute A_MONO from A_LEFT and A_RIGHT */
-      input->data[A_MONO][j] = Input_clamp((input->data[A_LEFT][i] + phase * input->data[A_RIGHT][i]) / 2);
-      input->data_u[A_MONO][j] = (input->data[A_MONO][j] + 1.0) / 2;
+      input->data[A_MONO][i] = (input->data[A_LEFT][i] + (phase * input->data[A_RIGHT][i])) / 2;
+      input->data_u[A_MONO][i] = (input->data[A_MONO][i] + 1.0) / 2.0;
     }
   }
 
   Input_do_fft(input);
-
-  pthread_mutex_unlock(&input->mutex);
 }
 
 
@@ -291,7 +256,7 @@ Input_random_float_range(Input_t *input, const float min, const float max)
   float rnd = input->data_u[A_MONO][input->roulette];
 #ifdef DEBUG
   if (max <= min)
-    xerror ("Input_random_short_range: max %f <= min %f\n", max, min);
+    xerror("Input_random_short_range: max %f <= min %f\n", max, min);
 #endif
   f = min + rnd * (max - min);
   do_roulette(input);
@@ -307,7 +272,7 @@ Input_random_short_range(Input_t *input, const short min, const short max)
   float rnd = input->data_u[A_MONO][input->roulette];
 #ifdef DEBUG
   if (max <= min)
-    xerror ("Input_random_short_range: max %d <= min %d\n", max, min);
+    xerror("Input_random_short_range: max %d <= min %d\n", max, min);
 #endif
   s = min + rnd * (max - min);
   do_roulette(input);
@@ -342,3 +307,10 @@ Input_get_volume(Input_t *input)
 
   return volume;
 }
+
+
+void
+Input_toggle_mute(Input_t *input)
+{
+  input->mute = !input->mute;
+}
