@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -21,8 +21,10 @@
 #define __BINIOU_INPUT_H
 
 #include <fftw3.h>
-
 #include "utils.h"
+#ifdef DEBUG
+#include "btimer.h"
+#endif
 
 /* A_STEREO is only used in calls to Input_set() */
 enum Channel { A_MONO=0, A_LEFT=1, A_RIGHT=2, A_STEREO };
@@ -36,9 +38,11 @@ typedef struct Input_s {
   fftw_plan plan_fft[3];
   
   /* input buffer size */
+  // FIXME make this a uint16_t
   uint32_t size;
 
   /* to get Mytho Random Numbers(c)(r)(tm) */
+  // FIXME make this a uint16_t
   uint32_t roulette;
 
   /* you can also mute the input  */
@@ -55,20 +59,22 @@ typedef struct Input_s {
   double *data_u[3];
 
   /* spectrum info */
+  // FIXME make this a uint16_t
   uint32_t spectrum_size;
 
   /* used to compute FFT */
-  double *out[3];
+  fftw_complex *out[3];
 
   double *spectrum[3];
-  double *spectrum_norme[3];
   double *spectrum_log[3];
-  double *spectrum_log_norme[3];
 
   double max_spectrum[3];
-  double max_spectrum_norme[3];
   double max_spectrum_log[3];
-  double max_spectrum_log_norme[3];
+
+  /* FFT timer */
+#ifdef DEBUG
+  BTimer_t *timer;
+#endif
 } Input_t;
 
 
@@ -92,4 +98,6 @@ short  Input_random_short_range(Input_t *, const short, const short);
 
 float  Input_get_volume(Input_t *);
 
+void   Input_toggle_mute(Input_t *);
+
 #endif /* INPUT_H */
