@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -35,7 +35,6 @@ extern u_short width;
 extern u_short height;
 #endif
 extern enum RandomMode random_mode;
-extern enum OSDMode osd_mode;
 extern char *pid_file;
 extern char *themes;
 
@@ -43,5 +42,6 @@ extern char *themes;
 void register_signals(void);
 void getargs(int, char **);
 void read_keyfile();
+void set_configuration(gchar *);
 
 #endif /* __MAIN_H */
