@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -93,8 +93,7 @@ Params3d_init(Params3d_t *p)
   }
   update(p);
 
-  /* OK: 	p->scale_factor = 120; */
-  p->scale_factor = HHEIGHT/1.333;
+  p->scale_factor = HEIGHT/(16.0/9.0);
   p->draw_boundary = 0;
 
   p->xs = p->xe = HWIDTH;
