@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -22,6 +22,32 @@
 #include "constants.h"
 #include "biniou.h"
 
+static gchar **blacklist = NULL;
+
+
+static int
+blacklisted(const char *name)
+{
+  gchar **p = blacklist;
+
+  if (p == NULL) {
+    return 0;
+  }
+  
+  while (*p != NULL) {
+    if (!strcmp(name, *p)) {
+#ifdef DEBUG
+      printf("[+] %s is blacklisted\n", name);
+#endif
+      return 1;
+    } else {
+      p++;
+    }
+  }
+
+  return 0;
+}
+
 
 Plugins_t *
 Plugins_new(const char *path)
@@ -53,6 +79,7 @@ Plugins_delete(Plugins_t *p)
   xfree(p->plugins);
   xfree(p->path);
   xfree(p);
+  g_strfreev(blacklist);
 }
 
 
@@ -172,6 +199,15 @@ Plugins_load(Plugins_t *ps)
     if (!isPluginDir(ps->path, name))
       continue;
 
+    /* check if plugin is in the blacklist */
+    if (blacklisted(name)) {
+#ifdef DEBUG
+      printf("[-] Skipping blacklisted plugin: %s\n", name);
+#endif
+      ps->size--;
+      continue;
+    }
+
     /* load the plugin */
     p = ps->plugins[i] = Plugin_new(ps->path, name, PL_MAIN);
     if (NULL != p) {
@@ -317,3 +353,10 @@ Plugins_reload_selected(Plugins_t *plugins)
 {
   Plugin_reload(plugins->selected);
 }
+
+
+void
+Plugins_set_blacklist(char **bl)
+{
+  blacklist = bl;
+}
