@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -33,7 +33,7 @@ mk_filename()
   rmkdir(blah);
   g_free(blah);
 
-  blah = g_strdup_printf("%s/." PACKAGE_NAME "/screenshots/biniou-%d-%06li.png",
+  blah = g_strdup_printf("%s/." PACKAGE_NAME "/screenshots/" PACKAGE_NAME "-%d-%06li.png",
 			 home_dir, getpid(), frame);
   frame++;
 
