@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -39,7 +39,6 @@ Sequence_load(const char *file)
   char *dot = NULL;
   gchar *blah = NULL;
   xmlChar *youhou;
-  const gchar *home_dir = NULL;
 
   if (file == NULL)
     xerror("Attempt to load a sequence with a NULL filename\n");
@@ -63,8 +62,7 @@ Sequence_load(const char *file)
   /*
    * build an XML tree from the file
    */
-  home_dir = g_get_home_dir();
-  blah = g_strdup_printf("%s/%s/%s", home_dir, SAVEDIR, file);
+  blah = g_strdup_printf("%s/%s", Sequences_get_dir(), file);
 
   doc = xmlParseFile(blah);
   g_free(blah);
