@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -88,8 +88,6 @@ void
 Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
 {
   char *filename = NULL;
-  gchar *blah = NULL;
-  const gchar *home_dir = NULL;
   Sequence_t *store = NULL;
 
   if (g_list_length(s->layers) == 0) {
@@ -108,10 +106,7 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
   }
 
   if (!overwrite || is_transient) {
-    struct timeval t;
-
-    gettimeofday(&t, NULL);
-    s->id = t.tv_sec;
+    s->id = unix_timestamp();
   }
 
   if (s->name != NULL)
@@ -119,15 +114,14 @@ Sequence_save(Sequence_t *s, int overwrite, const int is_transient)
   s->name = g_strdup_printf("%"PRIu32, s->id);
   printf("[s] Saving sequence %"PRIu32"\n", s->id);
 
-  home_dir = g_get_home_dir();
-  blah = g_strdup_printf("%s/%s", home_dir, SAVEDIR);
+  const gchar *blah = Sequences_get_dir();
   rmkdir(blah);
-  g_free(blah);
+  // g_free(blah);
 
   if (overwrite)
-    filename = g_strdup_printf("%s/%s/%s.xml", home_dir, SAVEDIR, s->name);
+    filename = g_strdup_printf("%s/%s.xml", blah, s->name);
   else
-    filename = g_strdup_printf("%s/%s/%"PRIu32".xml", home_dir, SAVEDIR, s->id);
+    filename = g_strdup_printf("%s/%"PRIu32".xml", blah, s->id);
 
   printf("[s] Filename: %s\n", filename);
 
