@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -43,9 +43,7 @@ Shuffler_new(const u_short size)
 void
 Shuffler_delete(Shuffler_t *s)
 {
-  assert(s != NULL);
-
-  if (s->size) {
+  if ((s != NULL) && s->size) {
     xfree(s->used);
     xfree(s->disabled);
   }
@@ -332,3 +330,16 @@ Shuffler_ok(const Shuffler_t *s)
 
   return (c != s->size);
 }
+
+
+enum ShufflerMode
+Shuffler_parse_mode(const char *opt)
+{
+  if (!strcasecmp(opt, "shuffle")) return BS_SHUFFLE;
+  if (!strcasecmp(opt, "cycle")) return BS_CYCLE;
+  if (!strcasecmp(opt, "random")) return BS_RANDOM;
+
+  xerror("Failed to parse shuffler mode '%s'\n", opt);
+
+  return BS_NONE; /* not reached */
+}
