@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -17,23 +17,25 @@
  *  along with lebiniou. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <inttypes.h>
 #include "spline.h"
 
 
 Spline_t *
-Spline_new(const u_char span, const u_long nb_cpoints)
+Spline_new(const uint8_t span, const int64_t nb_cpoints)
 {
-  u_char dd;
+  uint8_t dd;
   Spline_t *s = xcalloc(1, sizeof(Spline_t));
 
+  assert(nb_cpoints > 2);
   s->span = span;
   s->nb_cpoints = nb_cpoints;
 
-  s->nb_spoints = (s->nb_cpoints-1) * s->span + 1;
-  s->dt = 1.0 / (float)s->span;
+  s->nb_spoints = (s->nb_cpoints - 1) * s->span + 1;
+  s->dt = 1.0 / (double)s->span;
 
   for (dd = 0; dd < 8; dd++)
-    s->space[dd] = xcalloc(nb_cpoints, sizeof(float));
+    s->space[dd] = xcalloc(nb_cpoints, sizeof(double));
 
   s->cpoints = xcalloc(s->nb_cpoints, sizeof(Point3d_t));
   s->spoints = xcalloc(s->nb_spoints, sizeof(Point3d_t));
@@ -45,7 +47,7 @@ Spline_new(const u_char span, const u_long nb_cpoints)
 void
 Spline_delete(Spline_t *s)
 {
-  u_char dd;
+  uint8_t dd;
 
   xfree(s->cpoints);
   xfree(s->spoints);
@@ -62,15 +64,14 @@ Spline_compute(const Spline_t *s)
 {
   /* C'est parti */
 
-  float *a, *b, *c, *d;
-  float *h0, *h1, *h2, *h3, *hi_a;
-  short i, i1, imax;
-  float t;
-  u_char k;
+  double *a, *b, *c, *d;
+  double *h0, *h1, *h2, *h3, *hi_a;
+  int64_t i, i1, imax;
+  double t;
+  uint8_t k;
   Point3d_t *v;
-  const short nb_cpoints = s->nb_cpoints;
 
-  if (nb_cpoints < 2)
+  if (s->nb_cpoints < 2)
     return;
 
   h0 = s->space[0];
@@ -86,35 +87,35 @@ Spline_compute(const Spline_t *s)
 
     /* Trigonal system */
 
-    for (i = 0; i < nb_cpoints; i++)
+    for (i = 0; i < s->nb_cpoints; i++)
       d[i] = s->cpoints[i].coords[k];
 
-    for (i = 0, imax = nb_cpoints - 2; i < imax; i++) {
+    for (i = 0, imax = s->nb_cpoints - 2; i < imax; i++) {
       h3[i] = 3 * (d[i + 2] - 2 * d[i + 1] + d[i]);
       h2[i] = 1;
     }
-    h2[nb_cpoints - 3] = 0;
+    h2[s->nb_cpoints - 3] = 0;
 
     /* Dissolution of the system */
 
     a[0] = 4;
     h1[0] = h3[0] / a[0];
 
-    for (i = 1, i1 = 0, imax = nb_cpoints - 2; i < imax; i++, i1++) {
+    for (i = 1, i1 = 0, imax = s->nb_cpoints - 2; i < imax; i++, i1++) {
       h0[i1] = h2[i1] / a[i1];
       a[i]   = 4 - h0[i1];
       h1[i]  = (h3[i] - h1[i1]) / a[i];
     }
-    b[nb_cpoints - 3] = h1[nb_cpoints - 3];
+    b[s->nb_cpoints - 3] = h1[s->nb_cpoints - 3];
 
-    for (i = nb_cpoints - 4; i >= 0; i--)
+    for (i = s->nb_cpoints - 4; i >= 0; i--)
       b[i] = h1[i] - h0[i] * b[i + 1];
 
-    for (i = nb_cpoints - 2; i >= 1; i--)
+    for (i = s->nb_cpoints - 2; i >= 1; i--)
       b[i] = b[i - 1];
 
-    b[0] = b[nb_cpoints - 1] = 0;
-    hi_a = a + nb_cpoints - 1;
+    b[0] = b[s->nb_cpoints - 1] = 0;
+    hi_a = a + s->nb_cpoints - 1;
 
     for ( ; a < hi_a; a++, b++, c++, d++) {
       *c = *(d + 1) - *d - ( 2 * *b + *(b + 1)) / 3;
@@ -129,11 +130,12 @@ Spline_compute(const Spline_t *s)
 
 #ifdef DEBUG
     {
-      u_long lcount=0;
+      int64_t lcount = 0;
 #endif
       for ( ; a < hi_a; a++, b++, c++, d++)
 	for (t = 0; t < 1 - 1e-7; t += s->dt) {
-	  /* for (t = 0; t < 1.0 - s->dt; t += s->dt) { */
+	  // for (t = 0; t < 1.0 - s->dt; t += s->dt) {
+	  // printf("spoints= %ld, lcount= %ld\n", s->nb_spoints, lcount);
 	  (*v++).coords[k] = ((*a * t + *b) * t + *c) * t + *d;
 #ifdef DEBUG
 	  lcount++;
@@ -153,11 +155,9 @@ Spline_compute(const Spline_t *s)
 void
 Spline_info(const Spline_t *s)
 {
-  if (s == NULL)
-    xerror("Windows va redemarrer\n");
-  else {
+  if (s != NULL) {
     printf("[s] Spline has span: %d\n", s->span);
-    printf("[s] %li control points\n", s->nb_cpoints);
-    printf("[s] %li spline points\n", s->nb_spoints);
+    printf("[s] %"PRIu64" control points\n", s->nb_cpoints);
+    printf("[s] %"PRIu64" spline points\n", s->nb_spoints);
   }
 }
