@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -25,16 +25,16 @@
 
 
 typedef struct Spline_s {
-  u_char    span;
+  uint8_t    span;
 	
-  float     *space[8], dt;
+  double    *space[8], dt;
   Point3d_t *cpoints, *spoints;
-  u_long     nb_cpoints;
-  u_long     nb_spoints;
+  int64_t    nb_cpoints;
+  int64_t    nb_spoints;
 } Spline_t;
 
 
-Spline_t *Spline_new(const u_char, const u_long);
+Spline_t *Spline_new(const uint8_t, const int64_t);
 void Spline_delete(Spline_t *);
 
 void Spline_info(const Spline_t *);
