@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -227,3 +227,26 @@ parse_two_shorts(const char *str, const int delim, short *a, short *b)
 
   return rc;
 }
+
+
+/* returns 0 if command was executed, -1 otherwise */
+int
+check_command(const char *cmd)
+{
+  if (cmd != NULL) {
+    int res = system(cmd);
+    if (!res)
+      return 0;
+  }
+  return -1;
+}
+
+
+time_t
+unix_timestamp()
+{
+  struct timeval t;
+
+  gettimeofday(&t, NULL);
+  return t.tv_sec;
+}
