@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -60,5 +60,8 @@ int parse_two_shorts(const char *, const int, short *, short *);
 extern u_char       libbiniou_verbose;
 #define VERBOSE(X) if (libbiniou_verbose) X
 
-#endif /* __BINIOU_UTILS_H */
+int check_command(const char *);
 
+time_t unix_timestamp();
+
+#endif /* __BINIOU_UTILS_H */
