@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2018 Olivier Girondel
+ *  Copyright 1994-2019 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,6 +24,9 @@
 #if HAVE_LINUX_VIDEODEV2_H
 #include <linux/videodev2.h>
 #endif
+#if HAVE_SYS_VIDEOIO_H
+#include <sys/videoio.h>
+#endif
 #include "globals.h"
 
 #ifndef CAPTURE_SET
